#
# spec file for package tectonic
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tectonic
Version:        0.15.0
Release:        6.4
Summary:        Modernized self-contained TeX and LaTeX engine
License:        (Apache-2.0 OR MIT) AND BSD-3-Clause ) AND ( 0BSD OR MIT OR Apache-2.0 ) AND ( Apache-2.0 OR BSL-1.0 ) AND ( Apache-2.0 OR MIT ) AND ( Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT ) AND ( MIT OR Apache-2.0 AND BSD-2-Clause ) AND ( MIT OR Apache-2.0 OR Zlib ) AND ( MIT OR Zlib OR Apache-2.0 ) AND ( Unlicense OR MIT ) AND ( Zlib OR Apache-2.0 OR MIT ) AND Apache-2.0 AND BSD-2-Clause AND BSD-3-Clause AND CC0-1.0 AND ISC AND MIT AND WTFPL
Group:          Productivity/Publishing/TeX/Utilities
URL:            https://tectonic-typesetting.github.io
Source0:        https://github.com/tectonic-typesetting/tectonic/archive/refs/tags/%{name}@%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
Patch1:         0001-build-set-c-standard-to-c-17.patch
Patch2:         0002-fix-update-symbols-tags_from_lang-hb_ot_tag_from_lan.patch
%if 0%{?suse_version} > 1600
BuildRequires:  c++_compiler
BuildRequires:  c_compiler
%else
BuildRequires:  gcc13
BuildRequires:  gcc13-c++
BuildRequires:  libstdc++6-devel-gcc13
%endif
BuildRequires:  cargo-packaging
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(harfbuzz)
# https://github.com/tectonic-typesetting/tectonic/issues/1190
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)
ExclusiveArch:  %{rust_arches}

%description
Tectonic is a complete self-contained TeX/LaTeX engine powered by
XeTeX and TeXLive.

%prep
%autosetup -p1 -a1 -n %{name}-%{name}-%{version}

%build

%install
%if 0%{?suse_version} <= 1600
export CC=gcc-13
export CXX=g++-13
%endif
%{cargo_install} --features external-harfbuzz

%files
%{_bindir}/tectonic
%license LICENSE
%doc README.md

%changelog
* Thu Sep 26 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
-  Update vendored deps. This still won't resolve boo#1230089 as dependencies are
  hard dependencies so they won't be version bumped that easily.
* Tue Jun 18 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Fix leap builds
* Tue May 28 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Replace 0001-build-set-standard-to-c-17.patch to 0001-build-set-c-standard-to-c-17.patch
- Adjust patches for the release branch. tectonic uses a separate branch for releases
  so that's why the patches are failing
* Tue May 28 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update vendored dependencies.
- Apply the following patches for icu 75 support
  * 0001-build-set-standard-to-c-17.patch
  * 0002-fix-update-symbols-tags_from_lang-hb_ot_tag_from_lan.patch
- Update _service file and replace obsoleted "disabled" option
* Wed Apr 24 2024 Gordon Leung <pirateclip@protonmail.com>
- Remove redundant %%{cargo_build}
* Sun Mar 24 2024 Gordon Leung <pirateclip@protonmail.com>
- Update to version 0.15.0
  * The --web-bundle flag can now be used in more situations, specifically
    tectonic -X new and tectonic -X init
  * As part of the above work, you can now activate the "V2" interface with the
  - X flag in more places on the Tectonic command line.
  * The Tectonic.toml file used by the "V2" interface now supports a
    [metadata] section for arbitrary structured user metadata.
  * The "V2" interface also now supports external commands.
    If you have a program named tectonic-blah in your search path, running
    tectonic -X blah will execute it.
  * Running tectonic -Z help (as opposed to tectonic -Zhelp) now actuallyworks
    works
* Tue Jul  4 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.14.1
  * Bugfix release
- Update to version 0.14.0
  * Tectonic’s BibTeX engine has been partially translated from C to Rust
  Full changelog at https://github.com/tectonic-typesetting/tectonic/compare/tectonic%%400.13.1...tectonic%%400.14.1
* Tue May 23 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.13.1:
  * Fix a bug introduced in the previous release where custom commands in the
    tectonic -X watch mode break.
  * Update the version of the vendored Harfbuzz library to the latest, 7.3.0
    and all other cargo dependencies.
* Fri May 19 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.13.0
  * Add new V2 command `tectonic -X init`. This initializes a new document in
    the current directory much like `cargo init`.
  * Setting the `shell-escape-cwd` unstable option.
  * Update many developer dependencies to newer versions
* Fri Apr 14 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update of vendored dependencies
* Tue Feb 14 2023 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Sat Jan 28 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Lessen required memory to 8GB to enable arm builds.
* Sun Oct 30 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.12.0:
  * Partial support for the dvipdfmx:config special has been added.
  * A dumb crash was fixed when attempting to create HTML output
    with an input that has not been set up for the Tectonic HTML compilation
    framework.
  * preliminary official build for the Apple Metal platform.
* Fri Oct 14 2022 socvirnyl.estela@gmail.com
- Update to version 0.11.0:
  * bridge_harfbuzz: work around build failure with macOS SDK 10.9
  * engine_spx2html: make sure a code comment isn't treated as a test
  * engine_spx2html: fix clippy complaints
  * engine_spx2html: handle glyphs without associated ActualText
  * engine_spx2html: tidy up special handling and properly exit init on tdux:asp, tdux:dt, etc.
* Thu Jul 14 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- disabled tests since we updated the vendored dependencies:
  The cause of failure is just a check of difference of hashes between
  created files.
* Thu Jul 14 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for tectonic 0.9.0
